use common::sense; use open qw/:std :utf8/;  use Carp qw//; use File::Basename qw//; use File::Slurper qw//; use File::Spec qw//; use File::Path qw//; use Scalar::Util qw//;  use Test::More 0.98;  BEGIN {     $SIG{__DIE__} = sub {         my ($s) = @_;         if(ref $s) {             $s->{STACKTRACE} = Carp::longmess "?" if "HASH" eq Scalar::Util::reftype $s;             die $s;         } else {             die Carp::longmess defined($s)? $s: "undef"         }     };      my $t = File::Slurper::read_text(__FILE__);     my $s =  '/tmp/.liveman/perl-config/config'    ;     File::Path::rmtree($s) if -e $s;     File::Path::mkpath($s);     chdir $s or die "chdir $s: $!";      while($t =~ /^#\@> (.*)\n((#>> .*\n)*)#\@< EOF\n/gm) {         my ($file, $code) = ($1, $2);         $code =~ s/^#>> //mg;         File::Path::mkpath(File::Basename::dirname($file));         File::Slurper::write_text($file, $code);     }  } # 
# # NAME
# 
# config - Конфигуратор констант Perl-модуля
# 
# # VERSION
# 
# 1.4.1
# 
# # SYNOPSIS
# 
subtest 'SYNOPSIS' => sub { 
use config MY => 123;
::is scalar do {MY}, scalar do{123}, 'MY # -> 123';

# 
# # DESCRIPTION
# 
# См. `config::Manual`. Так как файл  `config.pm` перекрыт на metacpan.org файлом CONFIG.pm (ага – метацпан почему-то регистронезависим), то пришлось выкручиваться так )
# 
# # AUTHOR
# 
# Yaroslav O. Kosmina <dart@cpan.org>
# 
# # LICENSE
# 
# ⚖ **Perl5**
# 
# # COPYRIGHT
# 
# The config module is copyright (c) 2023 Yaroslav O. Kosmina. Rusland. All rights reserved.
	done_testing;
};

done_testing;
